@@ -18,6 +18,7 @@ from lfs.caching.utils import lfs_get_object_or_404
 from lfs.core.models import Shop
 from lfs.catalog.models import Category
 
+
 def l10n_float(string):
     """Takes a country specfic decimal value as string and returns a float.
     """
@@ -31,10 +32,16 @@ def l10n_float(string):
     except ValueError:
         return 0.0
 
+
 def get_default_shop():
     """Returns the default shop.
     """
-    return lfs_get_object_or_404(Shop, pk=1)
+    try:
+        shop = Shop.objects.get(pk=1)
+    except Shop.DoesNotExist, e:  # No guarantee that our shop will have pk=1 in postgres
+        shop = Shop.objects.all()[0]
+    return shop
+
 
 def lfs_quote(string, encoding="utf-8"):
     """Encodes passed string to passed encoding before quoting with
@@ -42,6 +49,7 @@ def lfs_quote(string, encoding="utf-8"):
     """
     return urllib.quote(string.encode(encoding))
 
+
 def import_module(module):
     """Imports module with given dotted name.
     """
@@ -52,6 +60,7 @@ def import_module(module):
         module = sys.modules[module]
     return module
 
+
 def set_message_to(response, msg):
     """Sets message cookie with passed message to passed response.
     """
@@ -64,6 +73,7 @@ def set_message_to(response, msg):
     response.set_cookie("message", lfs_quote(msg), max_age=max_age, expires=expires)
     return response
 
+
 def set_message_cookie(url, msg):
     """Returns a HttpResponseRedirect object with passed url and set cookie
     ``message`` with passed message.
@@ -79,14 +89,16 @@ def set_message_cookie(url, msg):
 
     return response
 
+
 def render_to_ajax_response(html=[], message=None):
     """Encodes given html and message to JSON and returns a HTTP response.
     """
     result = simplejson.dumps(
-        { "message" : message, "html" : html }, cls = LazyEncoder)
+        {"message": message, "html": html}, cls=LazyEncoder)
 
     return HttpResponse(result)
 
+
 def get_current_categories(request, object):
     """Returns all current categories based on given request. Current
     categories are the current selected category and all parent categories of
@@ -98,7 +110,7 @@ def get_current_categories(request, object):
         current_categories.extend(parents)
     elif object and object.content_type == "product":
         current_categories = []
-        category = lfs.catalog.utils.get_current_product_category(request, object)
+        category = object.get_current_category(request)
         while category:
             current_categories.append(category)
             category = category.parent
@@ -107,39 +119,43 @@ def get_current_categories(request, object):
 
     return current_categories
 
+
 def get_redirect_for(path):
     """Returns redirect path for the passed path.
     """
     try:
         redirect = Redirect.objects.get(
-            site = settings.SITE_ID, old_path = path)
+            site=settings.SITE_ID, old_path=path)
     except Redirect.DoesNotExist:
         return ""
     else:
         return redirect.new_path
 
+
 def set_redirect_for(old_path, new_path):
     """Sets redirect path for the passed path.
     """
     try:
-        redirect = Redirect.objects.get(site = settings.SITE_ID, old_path=old_path)
-        redirect.new_path=new_path
+        redirect = Redirect.objects.get(site=settings.SITE_ID, old_path=old_path)
+        redirect.new_path = new_path
         redirect.save()
     except Redirect.DoesNotExist:
         redirect = Redirect.objects.create(
             site_id=settings.SITE_ID, old_path=old_path, new_path=new_path)
 
+
 def remove_redirect_for(path):
     """Removes the redirect path for given path.
     """
     try:
-        redirect = Redirect.objects.get(site = settings.SITE_ID, old_path=path)
+        redirect = Redirect.objects.get(site=settings.SITE_ID, old_path=path)
     except Redirect.DoesNotExist:
         return False
     else:
         redirect.delete()
         return True
 
+
 def set_category_levels():
     """Sets the category levels based on the position in hierarchy.
     """
@@ -147,6 +163,7 @@ def set_category_levels():
         category.level = len(category.get_parents()) + 1
         category.save()
 
+
 def get_start_day(date):
     """Takes a string such as ``2009-07-23`` and returns datetime object of
     this day.
@@ -155,6 +172,7 @@ def get_start_day(date):
     start = datetime.datetime(int(year), int(month), int(day))
     return start
 
+
 def get_end_day(date):
     """Takes a string such as ``2009-07-23`` and returns a datetime object with
     last valid second of this day: 23:59:59.
@@ -165,6 +183,7 @@ def get_end_day(date):
 
     return end
 
+
 def getLOL(objects, objects_per_row=3):
     """Returns a list of list of the passed objects with passed objects per
     row.
@@ -173,7 +192,7 @@ def getLOL(objects, objects_per_row=3):
     row = []
     for i, object in enumerate(objects):
         row.append(object)
-        if (i+1) % objects_per_row == 0:
+        if (i + 1) % objects_per_row == 0:
             result.append(row)
             row = []
 
@@ -182,6 +201,7 @@ def getLOL(objects, objects_per_row=3):
 
     return result
 
+
 class LazyEncoder(simplejson.JSONEncoder):
     """Encodes django's lazy i18n strings.
     """
@@ -190,6 +210,7 @@ class LazyEncoder(simplejson.JSONEncoder):
             return force_unicode(obj)
         return obj
 
+
 class CategoryTree(object):
     """Represents a category tree.
     """
@@ -207,16 +228,16 @@ class CategoryTree(object):
         # category level 2) an the correct css is applied.
         level = 0
         categories = []
-        for category in Category.objects.filter(level = self.start_level):
+        for category in Category.objects.filter(level=self.start_level):
 
             if category.exclude_from_navigation:
                 continue
 
             if (self.currents and category in self.currents):
-                children = self._get_sub_tree(category, level+1)
+                children = self._get_sub_tree(category, level + 1)
                 is_current = True
             elif category.level <= self.expand_level:
-                children = self._get_sub_tree(category, level+1)
+                children = self._get_sub_tree(category, level + 1)
                 is_current = False
             else:
                 children = []
@@ -225,43 +246,43 @@ class CategoryTree(object):
             if self.start_level > 1:
                 if category.parent in self.currents:
                     categories.append({
-                        "category" : category,
-                        "children" : children,
-                        "level" : level,
-                        "is_current" : is_current,
+                        "category": category,
+                        "children": children,
+                        "level": level,
+                        "is_current": is_current,
                     })
             else:
                 categories.append({
-                    "category" : category,
-                    "children" : children,
-                    "level" : level,
-                    "is_current" : is_current,
+                    "category": category,
+                    "children": children,
+                    "level": level,
+                    "is_current": is_current,
                 })
 
         return categories
 
     def _get_sub_tree(self, category, level):
         categories = []
-        for category in Category.objects.filter(parent = category):
+        for category in Category.objects.filter(parent=category):
 
             if category.exclude_from_navigation:
                 continue
 
             if (self.currents and category in self.currents):
-                children = self._get_sub_tree(category, level+1)
+                children = self._get_sub_tree(category, level + 1)
                 is_current = True
             elif category.level <= self.expand_level:
-                children = self._get_sub_tree(category, level+1)
+                children = self._get_sub_tree(category, level + 1)
                 is_current = False
             else:
                 children = []
                 is_current = False
 
             categories.append({
-                "category" : category,
-                "children" : children,
-                "level" : level,
-                "is_current" : is_current,
+                "category": category,
+                "children": children,
+                "level": level,
+                "is_current": is_current,
             })
 
-        return categories
\ No newline at end of file
+        return categories
