@@ -465,16 +465,16 @@ def update_variants(request, product_id):
 
             elif key.startswith("property"):
                 # properties are marshalled as: property-variant_id|property_id
+                temp = key.split("-")[1]
+                variant_id, property_id = temp.split("|")
+                variant = Product.objects.get(pk=variant_id)
                 try:
-                    temp = key.split("-")[1]
-                    variant_id, property_id = temp.split("|")
-                    variant = Product.objects.get(pk=variant_id)
-                    property = variant.get_option(property_id)
-                    property.option_id = value
-                except (AttributeError, IndexError, ObjectDoesNotExist):
+                    ppv = variant.property_values.get(property=property_id, type=PROPERTY_VALUE_TYPE_VARIANT)
+                except ProductPropertyValue.DoesNotExist:
+                    # TODO: When creating new propertys (local or global), they are not copied onto existing variants.
                     continue
-                else:
-                    property.save()
+                ppv.value = value
+                ppv.save()
 
     # Refresh variant positions
     for i, variant in enumerate(product.variants.order_by("variant_position")):
