@@ -3,6 +3,7 @@ from django.core.urlresolvers import reverse
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
+
 class Manufacturer(models.Model):
     """The manufacturer is the unique creator of a product.
     """
@@ -14,5 +15,4 @@ class Manufacturer(models.Model):
     def get_absolute_url(self):
         """Returns the absolute url of the manufacturer
         """
-        return reverse(
-            "lfs_manufacturer", kwargs={ "manufacturer_id" : self.id })
\ No newline at end of file
+        return reverse("lfs_manufacturer", kwargs={"manufacturer_id": self.id})
