@@ -143,3 +143,7 @@ class PayPalOrderTransaction(models.Model):
 
 
 from listeners import *
+
+# See https://bitbucket.org/diefenbach/django-lfs/issue/197
+from paypal.standard.ipn.views import ipn
+ipn.csrf_exempt = True
