@@ -1,5 +1,6 @@
 # django imports
 from django import forms
+from django.template import RequestContext
 from django.template.loader import render_to_string
 
 # portlets imports
@@ -8,8 +9,9 @@ from portlets.models import Portlet
 # reviews imports
 import reviews.utils
 
+
 class AverageRatingPortlet(Portlet):
-    """A portlet to display recent visited products.
+    """Portlet to display the average rating for a product.
     """
     class Meta:
         app_label = 'portlet'
@@ -21,29 +23,27 @@ class AverageRatingPortlet(Portlet):
         """Renders the portlet as html.
         """
         product = context.get("product")
+        request = context.get("request")
 
         if product is None:
             d = {
-                "average" : False,
+                "average": False,
             }
         else:
             average, amount = reviews.utils.get_average_for_instance(product)
-            d = {
-                "title" : self.title,
-                "average" : average,
-                "amount" : amount,
-                "MEDIA_URL" : context.get("MEDIA_URL"),
-            }
 
-        return render_to_string("lfs/portlets/average_rating.html", d)
+        return render_to_string("lfs/portlets/average_rating.html", RequestContext(request, {
+            "title": self.title,
+            "average": average,
+            "amount": amount,
+        }))
 
     def form(self, **kwargs):
-        """
-        """
         return AverageRatingForm(instance=self, **kwargs)
 
+
 class AverageRatingForm(forms.ModelForm):
-    """
+    """Form for the AverageRatingPortlet.
     """
     class Meta:
-        model = AverageRatingPortlet
\ No newline at end of file
+        model = AverageRatingPortlet
