@@ -1,17 +1,19 @@
 # django imports
 from django import forms
+from django.conf import settings
 from django.core.cache import cache
+from django.template import RequestContext
 from django.template.loader import render_to_string
 
 # portlets imports
 from portlets.models import Portlet
-from portlets.utils import register_portlet
 
 # lfs imports
 from lfs.page.models import Page
 
+
 class PagesPortlet(Portlet):
-    """A portlet to display pages.
+    """Portlet to display pages.
     """
     class Meta:
         app_label = 'portlet'
@@ -22,25 +24,25 @@ class PagesPortlet(Portlet):
     def render(self, context):
         """Renders the portlet as html.
         """
-        cache_key = "pages"
+        request = context.get("request")
+
+        cache_key = "%s-pages" % settings.CACHE_MIDDLEWARE_KEY_PREFIX
         pages = cache.get(cache_key)
         if pages is None:
-            pages = Page.objects.active()
+            pages = Page.objects.filter(active=True, exclude_from_navigation=False)
             cache.set(cache_key, pages)
-        
-        return render_to_string("lfs/portlets/pages.html", {
-            "title" : self.title,
-            "pages" : pages,
-            "MEDIA_URL" : context.get("MEDIA_URL"),
-        })
+
+        return render_to_string("lfs/portlets/pages.html", RequestContext(request, {
+            "title": self.title,
+            "pages": pages,
+        }))
 
     def form(self, **kwargs):
-        """
-        """
         return PagesForm(instance=self, **kwargs)
 
+
 class PagesForm(forms.ModelForm):
-    """
+    """Form for the PagesPortlet.
     """
     class Meta:
         model = PagesPortlet
