@@ -2,18 +2,19 @@
 from django import forms
 from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
+from django.template import RequestContext
 from django.template.loader import render_to_string
 
 # portlets imports
 from portlets.models import Portlet
-from portlets.utils import register_portlet
 
 # lfs imports
 from lfs.catalog.models import Product
 from lfs.caching.utils import lfs_get_object
 
+
 class RecentProductsPortlet(Portlet):
-    """A portlet to display recent visited products.
+    """Portlet to display recent visited products.
     """
     class Meta:
         app_label = 'portlet'
@@ -24,7 +25,7 @@ class RecentProductsPortlet(Portlet):
     def render(self, context):
         """Renders the portlet as html.
         """
-        object = context.get("product")        
+        object = context.get("product")
         slug_not_to_display = ""
         limit = settings.LFS_RECENT_PRODUCTS_LIMIT
         if object:
@@ -44,19 +45,17 @@ class RecentProductsPortlet(Portlet):
                 product = product.get_default_variant()
             products.append(product)
 
-        return render_to_string("lfs/portlets/recent_products.html", {
-            "title" : self.title,
-            "products" : products,
-            "MEDIA_URL" : context.get("MEDIA_URL"),
-        })
+        return render_to_string("lfs/portlets/recent_products.html", RequestContext(request, {
+            "title": self.title,
+            "products": products,
+        }))
 
     def form(self, **kwargs):
-        """
-        """
         return RecentProductsForm(instance=self, **kwargs)
 
+
 class RecentProductsForm(forms.ModelForm):
-    """
+    """Form for the RecentProductsPortlet.
     """
     class Meta:
         model = RecentProductsPortlet
