@@ -1,14 +1,16 @@
 # django imports
 from django import forms
 from django.db import models
+from django.template import RequestContext
 from django.template.loader import render_to_string
 from django.utils.translation import ugettext_lazy as _
 
+# portlets imports
 from portlets.models import Portlet
-from portlets.utils import register_portlet
+
 
 class TextPortlet(Portlet):
-    """A simple portlet to display some text.
+    """Portlet to display some text.
     """
     text = models.TextField(_(u"Text"), blank=True)
 
@@ -21,16 +23,16 @@ class TextPortlet(Portlet):
     def render(self, context):
         """Renders the portlet as html.
         """
-        return render_to_string("lfs/portlets/text_portlet.html", {
-            "title" : self.title,
-            "text" : self.text
-        })
+        request = context.get("request")
+        return render_to_string("lfs/portlets/text_portlet.html", RequestContext(request, {
+            "title": self.title,
+            "text": self.text
+        }))
 
     def form(self, **kwargs):
-        """
-        """
         return TextPortletForm(instance=self, **kwargs)
 
+
 class TextPortletForm(forms.ModelForm):
     """Form for the TextPortlet.
     """
