@@ -11,6 +11,7 @@ from lfs.catalog.models import Category
 from lfs.catalog.models import Product
 from lfs.catalog.settings import STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, VARIANT
 
+
 def livesearch(request, template_name="lfs/search/livesearch_results.html"):
     """
     """
@@ -18,7 +19,7 @@ def livesearch(request, template_name="lfs/search/livesearch_results.html"):
 
     if q == "":
         result = simplejson.dumps({
-            "state" : "failure",
+            "state": "failure",
         })
     else:
         # Products
@@ -26,49 +27,49 @@ def livesearch(request, template_name="lfs/search/livesearch_results.html"):
                 Q(name__icontains=q) | \
                 Q(manufacturer__name__icontains=q) | \
                 Q(sku_manufacturer__icontains=q) & \
-                Q(sub_type__in = (STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, VARIANT))
-        
+                Q(sub_type__in=(STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, VARIANT))
+
         temp = Product.objects.filter(query)
         total = len(temp)
         products = temp[0:5]
-        
+
         products = render_to_string(template_name, RequestContext(request, {
-            "products" : products,
-            "q" : q,
-            "total" : total,
+            "products": products,
+            "q": q,
+            "total": total,
         }))
-        
+
         result = simplejson.dumps({
-            "state" : "success",
-            "products" : products,
+            "state": "success",
+            "products": products,
         })
     return HttpResponse(result)
-    
+
+
 def search(request, template_name="lfs/search/search_results.html"):
-    """Returns the search result according to given query (via get request) 
+    """Returns the search result according to given query (via get request)
     ordered by the globally set sorting.
     """
     q = request.GET.get("q", "")
-    
+
     # Products
-    query = Q(active=True) & \
-            Q(name__icontains=q) | \
+    query = Q(name__icontains=q) | \
             Q(manufacturer__name__icontains=q) | \
             Q(sku_manufacturer__icontains=q) & \
-            Q(sub_type__in = (STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, VARIANT))
-    products = Product.objects.filter(query)
+            Q(sub_type__in=(STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, VARIANT))
+    products = Product.objects.filter(query).filter(active=True)
 
     # Sorting
-    sorting = request.session.get("sorting")    
-    if sorting: 
+    sorting = request.session.get("sorting")
+    if sorting:
         products = products.order_by(sorting)
-        
+
     total = 0
     if products:
         total += len(products)
-        
+
     return render_to_response(template_name, RequestContext(request, {
-        "products" : products,
-        "q" : q,
-        "total" : total,
-    }))
\ No newline at end of file
+        "products": products,
+        "q": q,
+        "total": total,
+    }))
